resource "huaweicloud_vpc" "vpc" {
  name = "${var.app_name}-vpc"
  cidr = "192.168.0.0/16"
}

resource "huaweicloud_vpc_subnet" "subnet" {
  primary_dns = "100.79.1.250"
  vpc_id      = huaweicloud_vpc.vpc.id
  availability_zone = "cn-north-7c"
  name        = "${var.app_name}-subnet"
  cidr        = "192.168.0.0/24"
  gateway_ip  = "192.168.0.1"
}

resource "huaweicloud_vpc_eip" "eip" {
  name = "${var.app_name}-eip"
  bandwidth {
    charge_mode = "traffic"
    size        = "5"
    name        = "${var.app_name}-eip"
    share_type  = "PER"
  }
  publicip {
    type = "5_g-vm"
  }
}

resource "huaweicloud_cce_cluster" "cluster" {
  name                   = "${var.app_name}-cce"
  flavor_id              = "cce.s1.small"
  vpc_id                 = huaweicloud_vpc.vpc.id
  subnet_id              = huaweicloud_vpc_subnet.subnet.id
  container_network_type = "overlay_l2"
  cluster_version = "v1.19"
  eip                    = huaweicloud_vpc_eip.eip.address
  masters {
    availability_zone = "cn-north-7c"
  }
}

resource "huaweicloud_cce_node" "node" {
  cluster_id        = huaweicloud_cce_cluster.cluster.id
  name              = "${var.app_name}-node"
  flavor_id         = "s6.small.1"
  availability_zone = "cn-north-7c"
  password          = "CAM2022."
  subnet_id         = huaweicloud_vpc_subnet.subnet.id
  os = "CentOS 7.3 64bit"
  root_volume {
    size       = 40
    volumetype = "SATA"
  }
  data_volumes {
    size       = 100
    volumetype = "SATA"
  }
  eip_id = huaweicloud_vpc_eip.eip.id
}

resource "huaweicloud_servicestage_environment" "env" {
  name   = var.env_name
  vpc_id = huaweicloud_vpc.vpc.id

  basic_resources {
    id   = huaweicloud_cce_cluster.cluster.id
    type = "cce"
  }

  optional_resources {
    id   = huaweicloud_vpc_eip.eip.id
    type = "eip"
  }
}


resource "huaweicloud_servicestage_application" "app" {
  name = var.app_name
}
